@@ -17,7 +17,7 @@
 package org.kie.workbench.client;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.dashbuilder.client.cms.screen.explorer.ContentExplorerScreen;
+import org.dashbuilder.client.cms.screen.explorer.NavigationExplorerScreen;
 import org.dashbuilder.client.navigation.NavigationManager;
 import org.dashbuilder.client.navigation.event.NavTreeLoadedEvent;
 import org.dashbuilder.client.navigation.impl.NavigationManagerImpl;
@@ -80,7 +80,7 @@ public class KieWorkbenchEntryPointTest {
     private NavigationManager navigationManager;
 
     @Mock
-    protected ContentExplorerScreen contentExplorerScreen;
+    protected NavigationExplorerScreen navigationExplorerScreen;
 
     @Mock
     protected NavigationConstants navigationConstants;
@@ -124,10 +124,10 @@ public class KieWorkbenchEntryPointTest {
                                                                 adminPageHelper,
                                                                 navTreeDefinitions,
                                                                 navigationManager,
-                                                                contentExplorerScreen));
+                navigationExplorerScreen));
 
         doNothing().when(kieWorkbenchEntryPoint).hideLoadingPopup();
-        when(contentExplorerScreen.getNavTreeEditor()).thenReturn(navTreeEditor);
+        when(navigationExplorerScreen.getNavTreeEditor()).thenReturn(navTreeEditor);
     }
 
     @Test
@@ -159,9 +159,9 @@ public class KieWorkbenchEntryPointTest {
         NavGroup workbench = (NavGroup) navTree.getItemById(NavTreeDefinitions.GROUP_WORKBENCH);
 
         NavGroup design = (NavGroup) navTree.getItemById(NavTreeDefinitions.GROUP_DESIGN);
-        NavItem dashboard = navTree.getItemById(NavTreeDefinitions.ENTRY_DASHBOARDS);
+        NavItem pages = navTree.getItemById(NavTreeDefinitions.ENTRY_PAGES);
 
-        NavGroup devops = (NavGroup) navTree.getItemById(NavTreeDefinitions.GROUP_DEVOPS);
+        NavGroup deploy = (NavGroup) navTree.getItemById(NavTreeDefinitions.GROUP_DEPLOY);
         NavItem execServers = navTree.getItemById(NavTreeDefinitions.ENTRY_EXECUTION_SERVERS);
 
         NavGroup manage = (NavGroup) navTree.getItemById(NavTreeDefinitions.GROUP_MANAGE);
@@ -174,29 +174,28 @@ public class KieWorkbenchEntryPointTest {
         NavGroup track = (NavGroup) navTree.getItemById(NavTreeDefinitions.GROUP_TRACK);
         NavItem tasks = navTree.getItemById(NavTreeDefinitions.ENTRY_TASKS_LIST);
         NavItem processesAndTasksDashboard = navTree.getItemById(NavTreeDefinitions.ENTRY_PROCESSES_AND_TASKS_DASHBOARD);
-        NavItem businessDashboards = navTree.getItemById(NavTreeDefinitions.ENTRY_PROCESSES_AND_TASKS_DASHBOARD);
 
         assertNotNull(workbench);
         assertNotNull(design);
-        assertNotNull(devops);
+        assertNotNull(deploy);
         assertNotNull(manage);
         assertNotNull(track);
         assertEquals(design.getParent(),
                      workbench);
-        assertEquals(devops.getParent(),
+        assertEquals(deploy.getParent(),
                      workbench);
         assertEquals(manage.getParent(),
                      workbench);
         assertEquals(track.getParent(),
                      workbench);
 
-        assertNotNull(dashboard);
-        assertEquals(dashboard.getParent(),
+        assertNotNull(pages);
+        assertEquals(pages.getParent(),
                      design);
 
         assertNotNull(execServers);
         assertEquals(execServers.getParent(),
-                     devops);
+                     deploy);
 
         assertNotNull(processDef);
         assertNotNull(processInst);
@@ -216,12 +215,9 @@ public class KieWorkbenchEntryPointTest {
 
         assertNotNull(tasks);
         assertNotNull(processesAndTasksDashboard);
-        assertNotNull(businessDashboards);
         assertEquals(tasks.getParent(),
                      track);
         assertEquals(processesAndTasksDashboard.getParent(),
                      track);
-        assertEquals(businessDashboards.getParent(),
-                     track);
     }
 }
